Package: rifttable
Type: Package
Title: Results Tables to Bridge the Rift Between Epidemiologists and
        Their Data
Version: 0.7.2
Authors@R: 
    person(given = "Konrad H.",
           family = "Stopsack",
           role = c("aut", "cre", "cph"),
           email = "stopsack@post.harvard.edu",
           comment = c(ORCID = "0000-0002-0722-1311"))
Description: Presentation-ready results tables for epidemiologists in an 
    automated, reproducible fashion. The user provides the final analytical 
    dataset and specifies the design of the table, with rows and/or columns 
    defined by exposure(s), effect modifier(s), and estimands as desired, 
    allowing to show descriptors and inferential estimates in one table -- 
    bridging the rift between epidemiologists and their data, one table at a 
    time. See Rothman (2017) <doi:10.1007/s10654-017-0314-3>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: broom (>= 0.7.0), dplyr (>= 1.0.8), purrr, risks (>= 0.4.3),
        rlang (>= 0.4.0), stats, survival, stringr, tibble, tidyr
Suggests: gt (>= 0.8.0), knitr, markdown, quantreg, rmarkdown,
        sandwich, testthat (>= 3.0.0)
VignetteBuilder: knitr
URL: https://stopsack.github.io/rifttable/,
        https://github.com/stopsack/rifttable/
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-01-18 19:05:27 UTC; stopsack
Author: Konrad H. Stopsack [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-0722-1311>)
Maintainer: Konrad H. Stopsack <stopsack@post.harvard.edu>
Repository: CRAN
Date/Publication: 2026-01-18 19:50:02 UTC
Built: R 4.6.0; ; 2026-04-30 15:55:30 UTC; unix
